==> dxgl-src-0.5.8.zip: dxglcfg2/resource.h <==
#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDD_DXGLCFG                             100
#define IDI_DXGL                                101
#define IDI_DXGLSM                              102
#define IDI_STAR                                103
#define IDD_LOADING                             110
#define IDD_DISPLAY                             111
#define IDD_3DGRAPHICS                          112
#define IDD_EFFECTS                             113
#define IDD_ADVANCED                            114
#define IDD_DEBUG                               115
#define IDD_PATHS                               116
#define IDC_APPLY                               1000
#define IDC_APPS                                1001
#define IDC_ADD                                 1002
#define IDC_REMOVE                              1003
#define IDC_TABS                                1004
#define IDC_DEBUGLIST                           1005
#define IDC_SHADER                              1006
#define IDC_SORTMODES                           1007
#define IDC_TEXFILTER                           1008
#define IDC_TEXTUREFORMAT                       1009
#define IDC_ANISO                               1010
#define IDC_BROWSESHADER                        1011
#define IDC_TEXUPLOAD                           1012
#define IDC_VIDMODE                             1013
#define IDC_MSAA                                1014
#define IDC_PRIMARYSCALE                        1015
#define IDC_SCALE                               1016
#define IDC_WRITEINI                            1017
#define IDC_ASPECT                              1018
#define IDC_ASPECT3D                            1019
#define IDC_CUSTOMSCALELABEL                    1020
#define IDC_CUSTOMSCALELABELX                   1021
#define IDC_DPISCALE                            1022
#define IDC_COLORDEPTH                          1023
#define IDC_CUSTOMSCALEX                        1024
#define IDC_CUSTOMSCALELABELY                   1025
#define IDC_EXTRAMODES                          1026
#define IDC_CUSTOMSCALEY                        1027
#define IDC_VSYNC                               1028
#define IDC_COLOR                               1029
#define IDC_USESHADER                           1030
#define IDC_PROGRESS                            1031
#define IDC_DISPLAYNAME                         1032
#define IDC_PATHS                               1033
#define IDC_FIXEDSCALELABEL                     1034
#define IDC_FIXEDSCALELABELX                    1035
#define IDC_FIXEDSCALEX                         1036
#define IDC_FIXEDSCALELABELY                    1037
#define IDC_FIXEDSCALEY                         1038
#define IDC_FIXEDSCALESQUARE                    1039
#define IDC_LOWCOLORRENDER                      1040
#define IDC_FULLMODE                            1041

==> dxgl-src-0.5.11.zip: dxglcfg2/resource.h <==
// DXGL
// Copyright (C) 2011-2017 William Feely

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDD_DXGLCFG                             100
#define IDI_DXGL                                101
#define IDI_DXGLSM                              102
#define IDI_STAR                                103
#define IDD_LOADING                             110
#define IDD_DISPLAY                             111
#define IDD_3DGRAPHICS                          112
#define IDD_EFFECTS                             113
#define IDD_ADVANCED                            114
#define IDD_DEBUG                               115
#define IDD_PATHS                               116
#define IDC_APPLY                               1000
#define IDC_APPS                                1001
#define IDC_ADD                                 1002
#define IDC_REMOVE                              1003
#define IDC_TABS                                1004
#define IDC_DEBUGLIST                           1005
#define IDC_SHADER                              1006
#define IDC_SORTMODES                           1007
#define IDC_TEXFILTER                           1008
#define IDC_TEXTUREFORMAT                       1009
#define IDC_ANISO                               1010
#define IDC_BROWSESHADER                        1011
#define IDC_TEXUPLOAD                           1012
#define IDC_VIDMODE                             1013
#define IDC_MSAA                                1014
#define IDC_PRIMARYSCALE                        1015
#define IDC_SCALE                               1016
#define IDC_WRITEINI                            1017
#define IDC_ASPECT                              1018
#define IDC_ASPECT3D                            1019
#define IDC_CUSTOMSCALELABEL                    1020
#define IDC_CUSTOMSCALELABELX                   1021
#define IDC_DPISCALE                            1022
#define IDC_COLORDEPTH                          1023
#define IDC_CUSTOMSCALEX                        1024
#define IDC_CUSTOMSCALELABELY                   1025
#define IDC_EXTRAMODES                          1026
#define IDC_CUSTOMSCALEY                        1027
#define IDC_VSYNC                               1028
#define IDC_COLOR                               1029
#define IDC_USESHADER                           1030
#define IDC_PROGRESS                            1031
#define IDC_DISPLAYNAME                         1032
#define IDC_PATHS                               1033
#define IDC_FIXEDSCALELABEL                     1034
#define IDC_FIXEDSCALELABELX                    1035
#define IDC_FIXEDSCALEX                         1036
#define IDC_FIXEDSCALELABELY                    1037
#define IDC_FIXEDSCALEY                         1038
#define IDC_FIXEDSCALESQUARE                    1039
#define IDC_LOWCOLORRENDER                      1040
#define IDC_FULLMODE                            1041
#define IDC_PRESCALE                            1042
#define IDC_PRESCALESIZE                        1043
